# Import all Data Science python visualization package in single line

This package helps to setup your All Data Science python visualization package in single line.

Developed by Sunilkumar Prajapati.

## allvissone

allvissone is a python package offering a single line for all data science visualization. 


### Installation



#### Dependencies

`allvissone` is tested to work under Python 3.7+ and greater. The dependency requirements are based on the `allvissone` package update release:

- `matplotlib`(latest) - https://matplotlib.org/
- `seaborn`(latest) - https://seaborn.pydata.org/
- `bokeh`(latest) - https://docs.bokeh.org/en/latest/
- `altair`(latest) - https://altair-viz.github.io/getting_started/installation.html
- `Plotly`(latest) - https://plotly.com/python/
- `ggplot`(latest) - https://ggplot2.tidyverse.org/reference/ggplot.html
- `pygal`(latest) - http://www.pygal.org/en/stable/installing.html


#### Installation

* datascience is currently available on the PyPi's repository and you can install it via pip:

```bash
pip install -U allvissone
```

* If you prefer, you can clone it and run the setup.py file. Use the following commands to get a copy from GitHub and install all dependencies:

```bash
git clone https://github.com/Sunilkpraja/allvissone.git
cd allvissone
pip install .
```

* Or install using pip and GitHub:

```bash
pip install -U git+https://github.com/Sunilkpraja/allvissone.git
```